@@ -16,6 +16,7 @@ from rich.prompt import Confirm
 
 import nf_core.list
 import nf_core.utils
+from nf_core.lint_utils import dump_json_with_prettier
 
 log = logging.getLogger(__name__)
 
@@ -170,9 +171,7 @@ class PipelineSchema:
         num_params += sum(len(d.get("properties", {})) for d in self.schema.get("definitions", {}).values())
         if not suppress_logging:
             log.info(f"Writing schema with {num_params} params: '{self.schema_filename}'")
-        with open(self.schema_filename, "w") as fh:
-            json.dump(self.schema, fh, indent=4)
-            fh.write("\n")
+        dump_json_with_prettier(self.schema_filename, self.schema)
 
     def load_input_params(self, params_path):
         """Load a given a path to a parameters file (JSON/YAML)
@@ -183,7 +182,10 @@ class PipelineSchema:
         # First, try to load as JSON
         try:
             with open(params_path, "r") as fh:
-                params = json.load(fh)
+                try:
+                    params = json.load(fh)
+                except json.JSONDecodeError as e:
+                    raise UserWarning(f"Unable to load JSON file '{params_path}' due to error {e}")
                 self.input_params.update(params)
             log.debug(f"Loaded JSON input params: {params_path}")
         except Exception as json_e:
