@@ -327,7 +327,11 @@ class TestLaunch(unittest.TestCase):
         )
         # Check saved parameters file
         with open(self.nf_params_fn, "r") as fh:
-            saved_json = json.load(fh)
+            try:
+                saved_json = json.load(fh)
+            except json.JSONDecodeError as e:
+                raise UserWarning(f"Unable to load JSON file '{self.nf_params_fn}' due to error {e}")
+
         assert saved_json == {"input": "custom_input"}
 
     def test_build_command_params_cl(self):
